@@ -1,16 +1,21 @@
 package POE::Component::IRC::Plugin::Hailo;
+BEGIN {
+  $POE::Component::IRC::Plugin::Hailo::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $POE::Component::IRC::Plugin::Hailo::VERSION = '0.11';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use Carp;
 use Encode qw(encode_utf8 is_utf8);
+use List::Util qw(first);
 use POE;
 use POE::Component::Hailo;
 use POE::Component::IRC::Common qw(l_irc matches_mask_array irc_to_utf8 strip_color strip_formatting);
 use POE::Component::IRC::Plugin qw(PCI_EAT_NONE);
 
-our $VERSION = '0.10';
-
 sub new {
     my ($package, %args) = @_;
     my $self = bless \%args, $package;
@@ -87,6 +92,20 @@ sub hailo_learn_replied {
     return;
 }
 
+sub _ignoring_channel {
+    my ($self, $chan) = @_;
+
+    if ($self->{Channels}) {
+        unless ($self->{Own_channel} && $self->_is_own_channel($chan)) {
+            return if !first {
+                $chan = irc_to_utf8($chan) if is_utf8($_);
+                $_ == $chan
+            } @{ $self->{Channels} };
+        }
+    }
+    return;
+}
+
 sub _ignoring_user {
     my ($self, $user) = @_;
     
@@ -113,6 +132,7 @@ sub _msg_handler {
     my ($self, $kernel, $type, $user, $chan, $what) = @_[OBJECT, KERNEL, ARG0..$#_];
     my $nick = $self->{irc}->nick_name();
 
+    return if $self->_ignoring_channel($chan);
     return if $self->_ignoring_user($user);
     $what = _normalize_irc($what);
 
@@ -226,8 +246,7 @@ sub S_public {
 
 =head1 NAME
 
-POE::Component::IRC::Plugin::Hailo - A PoCo-IRC plugin which provides
-access to a L<Hailo|Hailo> conversation simulator.
+POE::Component::IRC::Plugin::Hailo - A PoCo-IRC plugin which provides access to a L<Hailo|Hailo> conversation simulator.
 
 =head1 SYNOPSIS
 
@@ -252,8 +271,8 @@ access to a L<Hailo|Hailo> conversation simulator.
  $irc->plugin_add('Connector', POE::Component::IRC::Plugin::Connector->new());
  $irc->plugin_add('Hailo', POE::Component::IRC::Plugin::Hailo->new(
      Own_channel    => '#bot_chan',
-     Ignore_regexes => [ qr{^\s*\w+://\S+\s*$} ], # ignore URL-only lines
-     Hailo_args => {
+     Ignore_regexes => [ qr{\w+://\w} ], # ignore lines containing URLs
+     Hailo_args     => {
          brain_resource => 'brain.sqlite',
      },
  ));
@@ -299,6 +318,10 @@ If this argument is not provided, the plugin will construct its own object.
 B<'Hailo_args'>, a hash reference containing arguments to pass to the
 constructor of a new L<Hailo|Hailo> object.
 
+B<'Channels'>, an array reference of channel names. If this is provided, the
+bot will only listen/respond the specified channels, rather than all
+channels (can be overridden with B<'Own_channel'>).
+
 B<'Own_channel'>, a channel where it will reply to all messages. The plugin
 will take care of joining the channel. It will part from it when the plugin
 is removed from the pipeline. Defaults to none.
